@@ -1,8 +1,8 @@
 /**********************************************************************
- * $Id: cu_algorithm.c 11212 2013-03-26 15:24:19Z pramsey $
+ * $Id: cu_algorithm.c 13247 2015-02-20 15:10:29Z pramsey $
  *
  * PostGIS - Spatial Types for PostgreSQL
- * http://postgis.refractions.net
+ * http://postgis.net
  * Copyright 2008 Paul Ramsey
  *
  * This is free software; you can redistribute and/or modify it under
@@ -895,28 +895,48 @@ static void test_geohash_point_as_int(void)
 	CU_ASSERT_EQUAL(gh, (unsigned int)4166944232);	
 }
 
+static void test_lwgeom_simplify(void)
+{
+		LWGEOM *l;
+		char *ewkt;
+
+		/* Not simplifiable */
+		l = lwgeom_simplify(lwgeom_from_wkt("LINESTRING(0 0, 50 1.00001, 100 0)", LW_PARSER_CHECK_NONE), 1.0);
+		ewkt = lwgeom_to_ewkt(l);
+		CU_ASSERT_STRING_EQUAL(ewkt, "LINESTRING(0 0,50 1.00001,100 0)");
+		lwgeom_free(l);
+		lwfree(ewkt);
+
+		/* Simplifiable */
+		l = lwgeom_simplify(lwgeom_from_wkt("LINESTRING(0 0,50 0.99999,100 0)", LW_PARSER_CHECK_NONE), 1.0);
+		ewkt = lwgeom_to_ewkt(l);
+		CU_ASSERT_STRING_EQUAL(ewkt, "LINESTRING(0 0,100 0)");
+		lwgeom_free(l);
+		lwfree(ewkt);
+}
 
 /*
 ** Used by test harness to register the tests in this file.
 */
-CU_TestInfo algorithms_tests[] =
+void algorithms_suite_setup(void);
+void algorithms_suite_setup(void)
 {
-	PG_TEST(test_lw_segment_side),
-	PG_TEST(test_lw_segment_intersects),
-	PG_TEST(test_lwline_crossing_short_lines),
-	PG_TEST(test_lwline_crossing_long_lines),
-	PG_TEST(test_lwline_crossing_bugs),
-	PG_TEST(test_lwpoint_set_ordinate),
-	PG_TEST(test_lwpoint_get_ordinate),
-	PG_TEST(test_point_interpolate),
-	PG_TEST(test_lwline_clip),
-	PG_TEST(test_lwline_clip_big),
-	PG_TEST(test_lwmline_clip),
-	PG_TEST(test_geohash_point),
-	PG_TEST(test_geohash_precision),
-	PG_TEST(test_geohash),
-	PG_TEST(test_geohash_point_as_int),
-	PG_TEST(test_isclosed),
-	CU_TEST_INFO_NULL
-};
-CU_SuiteInfo algorithms_suite = {"PostGIS Computational Geometry Suite",  init_cg_suite,  clean_cg_suite, algorithms_tests};
+	CU_pSuite suite = CU_add_suite("Computational Geometry", init_cg_suite, clean_cg_suite);
+	PG_ADD_TEST(suite,test_lw_segment_side);
+	PG_ADD_TEST(suite,test_lw_segment_intersects);
+	PG_ADD_TEST(suite,test_lwline_crossing_short_lines);
+	PG_ADD_TEST(suite,test_lwline_crossing_long_lines);
+	PG_ADD_TEST(suite,test_lwline_crossing_bugs);
+	PG_ADD_TEST(suite,test_lwpoint_set_ordinate);
+	PG_ADD_TEST(suite,test_lwpoint_get_ordinate);
+	PG_ADD_TEST(suite,test_point_interpolate);
+	PG_ADD_TEST(suite,test_lwline_clip);
+	PG_ADD_TEST(suite,test_lwline_clip_big);
+	PG_ADD_TEST(suite,test_lwmline_clip);
+	PG_ADD_TEST(suite,test_geohash_point);
+	PG_ADD_TEST(suite,test_geohash_precision);
+	PG_ADD_TEST(suite,test_geohash);
+	PG_ADD_TEST(suite,test_geohash_point_as_int);
+	PG_ADD_TEST(suite,test_isclosed);
+	PG_ADD_TEST(suite,test_lwgeom_simplify);
+}
