@@ -213,22 +213,21 @@ static void test_wkb_in_malformed(void)
 /*
 ** Used by test harness to register the tests in this file.
 */
-
-CU_TestInfo wkb_in_tests[] =
+void wkb_in_suite_setup(void);
+void wkb_in_suite_setup(void)
 {
-	PG_TEST(test_wkb_in_point),
-	PG_TEST(test_wkb_in_linestring),
-	PG_TEST(test_wkb_in_polygon),
-	PG_TEST(test_wkb_in_multipoint),
-	PG_TEST(test_wkb_in_multilinestring),
-	PG_TEST(test_wkb_in_multipolygon),
-	PG_TEST(test_wkb_in_collection),
-	PG_TEST(test_wkb_in_circularstring),
-	PG_TEST(test_wkb_in_compoundcurve),
-	PG_TEST(test_wkb_in_curvpolygon),
-	PG_TEST(test_wkb_in_multicurve),
-	PG_TEST(test_wkb_in_multisurface),
-	PG_TEST(test_wkb_in_malformed),
-	CU_TEST_INFO_NULL
-};
-CU_SuiteInfo wkb_in_suite = {"WKB In Suite",  init_wkb_in_suite,  clean_wkb_in_suite, wkb_in_tests};
+	CU_pSuite suite = CU_add_suite("WKB Input", init_wkb_in_suite, clean_wkb_in_suite);
+	PG_ADD_TEST(suite, test_wkb_in_point);
+	PG_ADD_TEST(suite, test_wkb_in_linestring);
+	PG_ADD_TEST(suite, test_wkb_in_polygon);
+	PG_ADD_TEST(suite, test_wkb_in_multipoint);
+	PG_ADD_TEST(suite, test_wkb_in_multilinestring);
+	PG_ADD_TEST(suite, test_wkb_in_multipolygon);
+	PG_ADD_TEST(suite, test_wkb_in_collection);
+	PG_ADD_TEST(suite, test_wkb_in_circularstring);
+	PG_ADD_TEST(suite, test_wkb_in_compoundcurve);
+	PG_ADD_TEST(suite, test_wkb_in_curvpolygon);
+	PG_ADD_TEST(suite, test_wkb_in_multicurve);
+	PG_ADD_TEST(suite, test_wkb_in_multisurface);
+	PG_ADD_TEST(suite, test_wkb_in_malformed);
+}
