@@ -59,7 +59,11 @@ findMemberByName(json_object* poObj, const char* pszName )
 
 	if( NULL != json_object_get_object(poTmp) )
 	{
-		assert( NULL != json_object_get_object(poTmp)->head );
+		if( NULL == json_object_get_object(poTmp)->head )
+		{
+			geojson_lwerror("invalid GeoJSON representation", 2);
+			return NULL;
+		}
 
 		for( it.entry = json_object_get_object(poTmp)->head;
 		        ( it.entry ?
@@ -90,7 +94,12 @@ parse_geojson_coord(json_object *poObj, int *hasz, POINTARRAY *pa)
 		const int nSize = json_object_array_length( poObj );
 		LWDEBUGF(3, "parse_geojson_coord called for array size %d.", nSize );
 
-
+		if ( nSize < 2 )
+		{
+			geojson_lwerror("Too few ordinates in GeoJSON", 4);
+			return LW_FAILURE;
+		}
+		
 		// Read X coordinate
 		poObjCoord = json_object_array_get_idx( poObj, 0 );
 		pt.x = json_object_get_double( poObjCoord );
@@ -101,7 +110,7 @@ parse_geojson_coord(json_object *poObj, int *hasz, POINTARRAY *pa)
 		pt.y = json_object_get_double( poObjCoord );
 		LWDEBUGF(3, "parse_geojson_coord pt.y = %f.", pt.y );
 
-		if( nSize == 3 ) /* should this be >= 3 ? */
+		if( nSize > 2 ) /* should this be >= 3 ? */
 		{
 			// Read Z coordinate
 			poObjCoord = json_object_array_get_idx( poObj, 2 );
@@ -109,21 +118,29 @@ parse_geojson_coord(json_object *poObj, int *hasz, POINTARRAY *pa)
 			LWDEBUGF(3, "parse_geojson_coord pt.z = %f.", pt.z );
 			*hasz = LW_TRUE;
 		}
-		else
+		else if ( nSize == 2 )
 		{
 			*hasz = LW_FALSE;
 			/* Initialize Z coordinate, if required */
 			if ( FLAGS_GET_Z(pa->flags) ) pt.z = 0.0;
 		}
-
-		/* TODO: should we account for nSize > 3 ? */
+		else 
+		{
+			/* TODO: should we account for nSize > 3 ? */
+			/* more than 3 coordinates, we're just dropping dimensions here... */
+		}
 
 		/* Initialize M coordinate, if required */
 		if ( FLAGS_GET_M(pa->flags) ) pt.m = 0.0;
 
 	}
+	else
+	{
+		/* If it's not an array, just don't handle it */
+		return LW_FAILURE;
+	}
 
-	return ptarray_append_point(pa, &pt, LW_FALSE);
+	return ptarray_append_point(pa, &pt, LW_TRUE);
 }
 
 static LWGEOM*
@@ -136,10 +153,11 @@ parse_geojson_point(json_object *geojson, int *hasz,  int root_srid)
 	LWDEBUGF(3, "parse_geojson_point called with root_srid = %d.", root_srid );
 
 	coords = findMemberByName( geojson, "coordinates" );
-	if ( ! coords ) {
+	if ( ! coords ) 
+	{
 		geojson_lwerror("Unable to find 'coordinates' in GeoJSON string", 4);
-    return NULL;
-  }
+		return NULL;
+	}
 	
 	pa = ptarray_construct_empty(1, 0, 1);
 	parse_geojson_coord(coords, hasz, pa);
@@ -162,8 +180,8 @@ parse_geojson_linestring(json_object *geojson, int *hasz,  int root_srid)
 	points = findMemberByName( geojson, "coordinates" );
 	if ( ! points ) {
 		geojson_lwerror("Unable to find 'coordinates' in GeoJSON string", 4);
-    return NULL;
-  }
+		return NULL;
+	}
 
 	pa = ptarray_construct_empty(1, 0, 1);
 
@@ -356,10 +374,11 @@ parse_geojson_multipolygon(json_object *geojson, int *hasz,  int root_srid)
 	}
 
 	poObjPolys = findMemberByName( geojson, "coordinates" );
-	if ( ! poObjPolys ) {
+	if ( ! poObjPolys )
+	{
 		geojson_lwerror("Unable to find 'coordinates' in GeoJSON string", 4);
-    return NULL;
-  }
+		return NULL;
+	}
 
 	if( json_type_array == json_object_get_type( poObjPolys ) )
 	{
@@ -432,10 +451,11 @@ parse_geojson_geometrycollection(json_object *geojson, int *hasz,  int root_srid
 	}
 
 	poObjGeoms = findMemberByName( geojson, "geometries" );
-	if ( ! poObjGeoms ) {
+	if ( ! poObjGeoms ) 
+	{
 		geojson_lwerror("Unable to find 'geometries' in GeoJSON string", 4);
-    return NULL;
-  }
+		return NULL;
+	}
 
 	if( json_type_array == json_object_get_type( poObjGeoms ) )
 	{
@@ -458,16 +478,18 @@ parse_geojson(json_object *geojson, int *hasz,  int root_srid)
 	json_object* type = NULL;
 	const char* name;
 
-	if( NULL == geojson ) {
+	if( NULL == geojson ) 
+	{
 		geojson_lwerror("invalid GeoJSON representation", 2);
-    return NULL;
-  }
+		return NULL;
+	}
 
 	type = findMemberByName( geojson, "type" );
-	if( NULL == type ) {
+	if( NULL == type ) 
+	{
 		geojson_lwerror("unknown GeoJSON type", 3);
-    return NULL;
-  }
+		return NULL;
+	}
 
 	name = json_object_get_string( type );
 
