@@ -1,8 +1,8 @@
 /**********************************************************************
- * $Id: lwsegmentize.c 11802 2013-08-14 07:42:48Z strk $
+ * $Id: lwsegmentize.c 13134 2014-12-01 08:47:21Z strk $
  *
  * PostGIS - Spatial Types for PostgreSQL
- * http://postgis.refractions.net
+ * http://postgis.net
  * Copyright 2001-2006 Refractions Research Inc.
  *
  * This is free software; you can redistribute and/or modify it under
@@ -306,7 +306,7 @@ lwcurvepoly_segmentize(const LWCURVEPOLY *curvepoly, uint32_t perQuad)
 		{
 			line = lwcircstring_segmentize((LWCIRCSTRING *)tmp, perQuad);
 			ptarray[i] = ptarray_clone_deep(line->points);
-			lwfree(line);
+			lwline_free(line);
 		}
 		else if (tmp->type == LINETYPE)
 		{
@@ -317,7 +317,7 @@ lwcurvepoly_segmentize(const LWCURVEPOLY *curvepoly, uint32_t perQuad)
 		{
 			line = lwcompound_segmentize((LWCOMPOUND *)tmp, perQuad);
 			ptarray[i] = ptarray_clone_deep(line->points);
-			lwfree(line);
+			lwline_free(line);
 		}
 		else
 		{
@@ -773,7 +773,7 @@ lwpolygon_desegmentize(LWPOLY *poly)
 	{
 		for (i=0; i<poly->nrings; i++)
 		{
-			lwfree(geoms[i]);
+			lwfree(geoms[i]); /* TODO: should this be lwgeom_free instead ? */
 		}
 		return lwgeom_clone((LWGEOM *)poly);
 	}
@@ -802,7 +802,7 @@ lwmline_desegmentize(LWMLINE *mline)
 	{
 		for (i=0; i<mline->ngeoms; i++)
 		{
-			lwfree(geoms[i]);
+			lwfree(geoms[i]); /* TODO: should this be lwgeom_free instead ? */
 		}
 		return lwgeom_clone((LWGEOM *)mline);
 	}
@@ -830,7 +830,7 @@ lwmpolygon_desegmentize(LWMPOLY *mpoly)
 	{
 		for (i=0; i<mpoly->ngeoms; i++)
 		{
-			lwfree(geoms[i]);
+			lwfree(geoms[i]); /* TODO: should this be lwgeom_free instead ? */
 		}
 		return lwgeom_clone((LWGEOM *)mpoly);
 	}
