@@ -1270,7 +1270,8 @@ ptarray_locate_point(const POINTARRAY *pa, const POINT4D *p4d, double *mindistou
 	double tlen, plen;
 	int t, seg=-1;
 	POINT4D	start4d, end4d, projtmp;
-	POINT2D start, end, proj, p;
+	POINT2D proj, p;
+	const POINT2D *start = NULL, *end = NULL;
 
 	/* Initialize our 2D copy of the input parameter */
 	p.x = p4d->x;
@@ -1278,12 +1279,22 @@ ptarray_locate_point(const POINTARRAY *pa, const POINT4D *p4d, double *mindistou
 	
 	if ( ! proj4d ) proj4d = &projtmp;
 
-	getPoint2d_p(pa, 0, &start);
+	/* If the pointarray has only one point, the nearest point is */
+	/* just that point */
+	if ( pa->npoints == 1 )
+	{
+		getPoint4d_p(pa, 0, proj4d);
+		*mindistout = distance2d_pt_pt(&p, start);
+		return 0.0;
+	}
+
+	/* Loop through pointarray looking for nearest segment */ 
+	start = getPoint2d_cp(pa, 0);
 	for (t=1; t<pa->npoints; t++)
 	{
 		double dist;
-		getPoint2d_p(pa, t, &end);
-		dist = distance2d_pt_seg(&p, &start, &end);
+		end = getPoint2d_cp(pa, t);
+		dist = distance2d_pt_seg(&p, start, end);
 
 		if (t==1 || dist < mindist )
 		{
@@ -1320,7 +1331,7 @@ ptarray_locate_point(const POINTARRAY *pa, const POINT4D *p4d, double *mindistou
 	LWDEBUGF(3, "Closest segment:%d, npoints:%d", seg, pa->npoints);
 
 	/* For robustness, force 1 when closest point == endpoint */
-	if ( (seg >= (pa->npoints-2)) && p2d_same(&proj, &end) )
+	if ( (seg >= (pa->npoints-2)) && p2d_same(&proj, end) )
 	{
 		return 1.0;
 	}
@@ -1336,16 +1347,16 @@ ptarray_locate_point(const POINTARRAY *pa, const POINT4D *p4d, double *mindistou
 	if ( tlen == 0 ) return 0;
 
 	plen=0;
-	getPoint2d_p(pa, 0, &start);
+	start = getPoint2d_cp(pa, 0);
 	for (t=0; t<seg; t++, start=end)
 	{
-		getPoint2d_p(pa, t+1, &end);
-		plen += distance2d_pt_pt(&start, &end);
+		end = getPoint2d_cp(pa, t+1);
+		plen += distance2d_pt_pt(start, end);
 
 		LWDEBUGF(4, "Segment %d made plen %g", t, plen);
 	}
 
-	plen+=distance2d_pt_pt(&proj, &start);
+	plen+=distance2d_pt_pt(&proj, start);
 
 	LWDEBUGF(3, "plen %g, tlen %g", plen, tlen);
 
@@ -1433,45 +1444,47 @@ static void
 ptarray_dp_findsplit(POINTARRAY *pts, int p1, int p2, int *split, double *dist)
 {
 	int k;
-	POINT2D pa, pb, pk;
-	double tmp;
+	const POINT2D *pk, *pa, *pb;
+	double tmp, d;
 
 	LWDEBUG(4, "function called");
 
-	*dist = -1;
 	*split = p1;
+	d = -1;
 
 	if (p1 + 1 < p2)
 	{
 
-		getPoint2d_p(pts, p1, &pa);
-		getPoint2d_p(pts, p2, &pb);
+		pa = getPoint2d_cp(pts, p1);
+		pb = getPoint2d_cp(pts, p2);
 
 		LWDEBUGF(4, "P%d(%f,%f) to P%d(%f,%f)",
-		         p1, pa.x, pa.y, p2, pb.x, pb.y);
+		         p1, pa->x, pa->y, p2, pb->x, pb->y);
 
 		for (k=p1+1; k<p2; k++)
 		{
-			getPoint2d_p(pts, k, &pk);
+			pk = getPoint2d_cp(pts, k);
 
-			LWDEBUGF(4, "P%d(%f,%f)", k, pk.x, pk.y);
+			LWDEBUGF(4, "P%d(%f,%f)", k, pk->x, pk->y);
 
 			/* distance computation */
-			tmp = distance2d_pt_seg(&pk, &pa, &pb);
+			tmp = distance2d_sqr_pt_seg(pk, pa, pb);
 
-			if (tmp > *dist)
+			if (tmp > d)
 			{
-				*dist = tmp;	/* record the maximum */
+				d = tmp;	/* record the maximum */
 				*split = k;
 
-				LWDEBUGF(4, "P%d is farthest (%g)", k, *dist);
+				LWDEBUGF(4, "P%d is farthest (%g)", k, d);
 			}
 		}
+		*dist = d;
 
 	} /* length---should be redone if can == 0 */
 	else
 	{
 		LWDEBUG(3, "segment too short, no split/no dist");
+		*dist = -1;
 	}
 
 }
@@ -1486,6 +1499,8 @@ ptarray_simplify(POINTARRAY *inpts, double epsilon, unsigned int minpts)
 	POINTARRAY *outpts;
 	POINT4D pt;
 
+	double eps_sqr = epsilon * epsilon;
+
 	/* Allocate recursion stack */
 	stack = lwalloc(sizeof(int)*inpts->npoints);
 
@@ -1509,7 +1524,7 @@ ptarray_simplify(POINTARRAY *inpts, double epsilon, unsigned int minpts)
 
 		LWDEBUGF(3, "Farthest point from P%d-P%d is P%d (dist. %g)", p1, stack[sp], split, dist);
 
-		if (dist > epsilon || ( outpts->npoints+sp+1 < minpts && dist > 0 ) )
+		if (dist > eps_sqr || ( outpts->npoints+sp+1 < minpts && dist >= 0 ) )
 		{
 			LWDEBUGF(4, "Added P%d to stack (outpts:%d)", split, sp);
 			stack[++sp] = split;
@@ -1517,6 +1532,7 @@ ptarray_simplify(POINTARRAY *inpts, double epsilon, unsigned int minpts)
 		else
 		{
 			getPoint4d_p(inpts, stack[sp], &pt);
+			LWDEBUGF(4, "npoints , minpoints %d %d", outpts->npoints, minpts);
 			ptarray_append_point(outpts, &pt, LW_FALSE);
 			
 			LWDEBUGF(4, "Added P%d to simplified point array (size: %d)", stack[sp], outpts->npoints);
