@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: geography_inout.c 11384 2013-05-08 20:37:12Z pramsey $
+ * $Id: geography_inout.c 13368 2015-03-20 14:06:44Z pramsey $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * Copyright 2009-2011 Paul Ramsey <pramsey@cleverelephant.ca>
@@ -104,7 +104,7 @@ GSERIALIZED* gserialized_geography_from_lwgeom(LWGEOM *lwgeom, int32 geog_typmod
 	/* Check for typmod agreement */
 	if ( geog_typmod >= 0 )
 	{
-		postgis_valid_typmod(g_ser, geog_typmod);
+		g_ser = postgis_valid_typmod(g_ser, geog_typmod);
 		POSTGIS_DEBUG(3, "typmod and geometry were consistent");
 	}
 	else
@@ -558,7 +558,7 @@ Datum geography_from_binary(PG_FUNCTION_ARGS)
 	if ( ! lwgeom )
 		lwerror("Unable to parse WKB");
  		
-	gser = gserialized_geography_from_lwgeom(lwgeom, 0);
+	gser = gserialized_geography_from_lwgeom(lwgeom, -1);
 	lwgeom_free(lwgeom);
 	PG_RETURN_POINTER(gser);
 }
@@ -567,7 +567,7 @@ Datum geography_from_binary(PG_FUNCTION_ARGS)
 PG_FUNCTION_INFO_V1(geography_from_geometry);
 Datum geography_from_geometry(PG_FUNCTION_ARGS)
 {
-	GSERIALIZED *geom = (GSERIALIZED*)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
+	GSERIALIZED *geom = (GSERIALIZED*)PG_DETOAST_DATUM_COPY(PG_GETARG_DATUM(0));
 	LWGEOM *lwgeom = NULL;
 	GSERIALIZED *g_ser = NULL;
 
